@@ -1,15 +1,19 @@
 import configparser
 from pathlib import Path
-from typing import Optional
-
-import git
-import git.exc
+from typing import TYPE_CHECKING, Optional
 
 # XXX: This is hacky. This should maybe use the Context object or something to
 # determine the base directory.
 
+if TYPE_CHECKING:
+    # Only import when type checking to avoid loading module when unecessary
+    import git  # noqa
+
+
+def repo(path: Optional[Path] = None) -> Optional["git.Repo"]:
+    # import inside def for performance
+    import git.exc
 
-def repo(path: Optional[Path] = None) -> Optional[git.Repo]:
     try:
         r = git.Repo(str(path or Path.cwd()), search_parent_directories=True)
         return r
@@ -30,6 +34,19 @@ def user_email(path: Optional[Path] = None) -> Optional[str]:
         return None
 
 
+def global_ignore_path(path: Optional[Path] = None) -> Optional[Path]:
+    r = repo(path)
+    if r is None:
+        return None
+
+    try:
+        return Path(r.config_reader("global").get_value("core", "excludesfile").strip())
+    except configparser.NoSectionError:
+        return None
+    except configparser.NoOptionError:
+        return None
+
+
 def url(path: Optional[Path] = None) -> Optional[str]:
     """Get remote.origin.url for git dir at dirPath"""
     r = repo(path)
@@ -47,4 +64,8 @@ def commit(path: Optional[Path] = None) -> Optional[str]:
     r = repo()
     if r is None:
         return None
-    return str(r.head.commit)
+    try:
+        return str(r.head.commit)
+    except ValueError:
+        # catch case where local git repo without remote master
+        return None
