@@ -10,11 +10,11 @@ BASE_PATH = THIS_PATH / ".."
 
 def test_tool_from_config_found() -> None:
     """Validates that existing tools are parsed from the config file"""
-    config: Dict[str, Any] = {"tools": {"r2c.eslint": {"ignore": []}}}
+    config: Dict[str, Any] = {"tools": {"eslint": {"ignore": []}}}
     context = bento.context.Context(config=config)
     tools = context.tools
     assert len(tools) == 1
-    assert tools.keys() == {"r2c.eslint"}
+    assert tools.keys() == {"eslint"}
 
 
 def test_tool_from_config_missing() -> None:
@@ -25,28 +25,8 @@ def test_tool_from_config_missing() -> None:
 
 
 def test_loads_ignores(monkeypatch: MonkeyPatch) -> None:
-    context = bento.context.Context(base_path=(Path(BASE_PATH) / "bento" / "configs"))
-    expected = {
-        "*.min.js",
-        "*.egg-info/",
-        ".bento/",
-        ".eggs/",
-        ".git/",
-        ".mypy_cache/",
-        "__pycache__/",
-        "build/",
-        "develop-eggs/",
-        "dist/",
-        "eggs/",
-        "lib/",
-        "lib64/",
-        "node_modules/",
-        "packages/",
-        "parts/",
-        "pip-wheel-metadata/",
-        "sdist/",
-        "share/python-wheels/",
-        "var/",
-        "wheels/",
-    }
+    context = bento.context.Context(
+        base_path=(Path(BASE_PATH) / "bento" / "configs"), is_init=True
+    )
+    expected = {".bento/", ".git/", ".gitignore"}
     assert context.file_ignores.patterns == expected
